@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Text::CSV);
 
-our $VERSION = '0.399_001';
+our $VERSION = '0.399_002';
 
 sub new {
     my ($self, $hash) = @_;
@@ -19,7 +19,7 @@ sub new {
 
 sub combine {
     my $self = shift;
-    for (grep defined, @_) { return unless _ok(); }
+    for (grep defined, @_) { return if _bad(); }
     return $self->SUPER::combine(@_);
 }
 
@@ -27,12 +27,12 @@ sub parse {
     my $self = shift;
     for (map +$_, grep defined, @_) {
 	    chomp;
-	    return unless _ok();
+	    return if _bad();
     }
     return $self->SUPER::parse( @_ );
 }
 
-sub _ok { m{\A [\t \P{Cntrl}]* \z}x; }	# test $_
+sub _bad { m{ [^\t\P{Cntrl}] }x; }	# test $_
 
 1;
 
@@ -155,7 +155,8 @@ See HASH option to C<< ->new >>.
 =head1 DEPENDENCIES
 
 perl 5.8.0
-Text::CSV
+
+Text::CSV 1.0
 
 =head1 VERSION
 
